@@ -141,7 +141,7 @@ void WakeUpModel::reload()
             } else {
                 KService::Ptr service = KService::serviceByStorageId(name + ".desktop");
                 if (service) {
-                    it->prettyName = service->property("Name", QVariant::Invalid).toString();
+                    it->prettyName = service->property(QStringLiteral("Name"), QVariant::Invalid).toString();
                     it->iconName = service->icon();
 
                     m_applicationInfo.insert(name, qMakePair((*it).prettyName, (*it).iconName));
